@@ -629,13 +629,13 @@
 ; move format: ((board . info) start-slot card card-count end-slot)
 (define (create-help-list board moves)
   (if (null? moves)
-    (list 0 (_"No moves available"))
+    (list 0 (_"No moves are possible. Undo or start again."))
     (let* ((best-move (car moves))
 	   (from-card (caddr best-move))
 	   (to-slot   (list-ref best-move 4))
 	   (to-stack  (vector-ref board to-slot)))
       (if (eq? (vector-ref (cdar best-move) index-outcome) outcome-lose)
-	(list 0 (_"game has no solution"))
+	(list 0 (_"The game has no solution. Undo or start again."))
 	(list 1 (get-name from-card)
 	      (cond ((freecell? to-slot)  (_"an empty reserve"))
 		    ((homecell? to-slot)  (_"the foundation"))
