@@ -18,6 +18,10 @@
 
 (def-save-var free-reserves 0)
 
+(define foundation '(0 1 6 7))
+(define freecells '(2 3 4 5))
+(define tableau '(8 9 10 11 12 13 14 15 16 17))
+
 (define (new-game)
   (initialize-playing-area)
   (set-ace-low)
@@ -193,18 +197,29 @@
 	      (deal-cards slot (list f-slot))))
 	(#t (move-to-foundation slot (+ 1 f-slot)))))
 
+(define (autoplay-foundations)
+  (define (autoplay-foundations-tail)
+    (if (or-map button-double-clicked (append freecells tableau))
+        (autoplay-foundations-tail)
+        #t))
+  (if (or-map button-double-clicked (append freecells tableau))
+      (autoplay-foundations-tail)
+      #f))
+
 (define (button-double-clicked slot-id)
-  (and (not (empty-slot? slot-id))
-       (> slot-id 1)
-       (or (< slot-id 6)
-	   (> slot-id 7))
-       (or (and (= (get-value (get-top-card slot-id))
-		   ace)
-		(move-to-empty-foundation slot-id 0))
-	   (move-to-foundation slot-id 0))
-       (add-to-score! 1)
-       (or (> slot-id 7)
-	   (set! free-reserves (+ 1 free-reserves)))))
+  (or (and (member slot-id foundation)
+	   (autoplay-foundations))
+      (and (not (empty-slot? slot-id))
+	   (> slot-id 1)
+	   (or (< slot-id 6)
+	       (> slot-id 7))
+	   (or (and (= (get-value (get-top-card slot-id))
+		       ace)
+		    (move-to-empty-foundation slot-id 0))
+	       (move-to-foundation slot-id 0))
+	   (add-to-score! 1)
+	   (or (> slot-id 7)
+	       (set! free-reserves (+ 1 free-reserves))))))
 
 (define (game-continuable)
   (and (not (game-won))
