@@ -2,7 +2,7 @@
 /*
  * Blackjack - blackjack.h
  *
- * Copyright (C) 2003-2004 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2003-2005 William Jon McCann <mccann@jhu.edu>
  *
  * This game is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,8 +24,8 @@
 
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
-#include "press_data.h"
 
+#include "press_data.h"
 #include "strategy.h"
 
 // Constants
@@ -56,6 +56,7 @@
 #define GCONF_KEY_GAME_VARIATION     GCONF_KEY_DIR "/settings/variation"
 #define GCONF_KEY_SHOW_PROBABILITIES GCONF_KEY_DIR "/settings/show_probabilities"
 #define GCONF_KEY_QUICK_DEAL         GCONF_KEY_DIR "/settings/quick_deal"
+#define GCONF_KEY_NEVER_INSURANCE    GCONF_KEY_DIR "/settings/never_insurance"
 #define GCONF_KEY_SHOW_TOOLBAR       GCONF_KEY_DIR "/toolbar"
 #define GCONF_KEY_DECK_OPTIONS       GCONF_KEY_DIR "/deck/options"
 #define GCONF_KEY_CARD_STYLE         GCONF_KEY_DIR "/deck/card_style"
@@ -87,8 +88,6 @@ extern guint            y_spacing;
 extern double           x_expanded_offset;
 extern double           y_expanded_offset;
 
-extern gboolean         events_pending;
-
 gboolean                bj_quit_app (void);
 void                    bj_make_window_title (gchar *game_name);
 void                    bj_update_control_menu (void);
@@ -113,6 +112,8 @@ gboolean                bj_get_show_toolbar (void);
 void                    bj_set_show_toolbar (gboolean);
 gboolean                bj_get_quick_deal (void);
 void                    bj_set_quick_deal (gboolean);
+gboolean                bj_get_never_insurance (void);
+void                    bj_set_never_insurance (gboolean);
 gchar                  *bj_get_game_variation (void);
 void                    bj_set_game_variation (const gchar *);
 
