@@ -44,12 +44,12 @@ typedef enum {
 	LEVEL_STRONG
 } LevelID;
 
+extern PlayerID  who_starts;
 
-void game_reset (gboolean start);
+void game_reset (void);
 void prompt_player (void);
 void on_dialog_close (GtkWidget *w, int response_id, gpointer data);
 void scorebox_update (void);
 void scorebox_reset (void);
-void toolbar_changed (void);
 gint get_random_int (gint n);
 
