@@ -28,6 +28,7 @@
 
 #include <games-gridframe.h>
 #include <games-stock.h>
+#include <games-scores.h>
 
 #include "main.h"
 #include "properties.h"
@@ -38,11 +39,28 @@
 #include "preferences.h"
 #include "scoreboard.h"
 #include "network.h"
+#include "warp.h"
 
 GtkWidget *window;
 GtkWidget *drawing_area;
 GtkWidget *appbar;
 
+static const GamesScoresCategory scorecats[] = {{"4.0", N_("Beginner")},
+						{"3.0", N_("Slow")},
+						{"2.0", N_("gnibbles|Medium")},
+						{"1.0", N_("Fast")},
+						{"4.1", N_("Beginner with Fakes")},
+						{"3.1", N_("Slow with Fakes")},
+						{"2.1", N_("Medium with Fakes")},
+						{"1.1", N_("Fast with Fakes")},
+						GAMES_SCORES_LAST_CATEGORY };
+static const GamesScoresDescription scoredesc = {scorecats,
+						 "4.0",
+						 "gnibbles",
+						 GAMES_SCORES_STYLE_PLAIN_DESCENDING};
+
+GamesScores *highscores;
+
 extern GdkPixmap *buffer_pixmap;
 extern GdkPixbuf *logo_pixmap;
 
@@ -143,14 +161,20 @@ about_cb (GtkAction *action, gpointer data)
 {
 	const gchar *authors[] = {"Sean MacIsaac", "Ian Peters", NULL};
 
+	const gchar *documenters[] = {"Kevin Breit", NULL};
+
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "name", _("Nibbles"), 
 			       "version", VERSION,
-			       "copyright", "Copyright \xc2\xa9 1999-2004 Sean MacIsaac, Ian Peters",
+			       "copyright", "Copyright \xc2\xa9 1999-2006 Sean MacIsaac, Ian Peters",
+			       "license", "GPL 2+",
 			       "comments", _("A worm game for GNOME."),
 			       "authors", authors,
+			       "documenters", documenters,
 			       "translator-credits", _("translator-credits"),
 			       "logo-icon-name", "gnome-nibbles",
+			       "website", "http://www.gnome.org/projects/gnome-games/",
+			       "wrap-license", TRUE,
 			       NULL);
 }
 
@@ -177,8 +201,9 @@ draw_board ()
 {
 	int i, j;
 
-	for (i = 0; i < BOARDWIDTH; i++)
-		for (j = 0; j < BOARDHEIGHT; j++)
+	for (i = 0; i < BOARDWIDTH; i++) {
+		for (j = 0; j < BOARDHEIGHT; j++) {
+			gnibbles_draw_pixmap_buffer (0, i, j);
 			if (board[i][j] >= EMPTYCHAR &&
 			    board[i][j] < EMPTYCHAR + 19) {
 				gnibbles_draw_pixmap_buffer (
@@ -191,14 +216,17 @@ draw_board ()
 			} else if (board[i][j] >= 'A' && board[i][j] < 'J') {
 				/* bonus */
 			} else {
-				g_warning("Unknown board charact at "
-					  "%d, %d: '%c' (%u)\n", i, j,
-					  board[i][j], board[i][j]);
+				/* Warp point. */
 			}
+		}
+	}
 
 	for (i=0; i<boni->numbonuses; i++)
 		gnibbles_bonus_draw (boni->bonuses[i]);
 
+	for (i=0; i<warpmanager->numwarps; i++)
+		gnibbles_warp_draw_buffer (warpmanager->warps[i]);
+
 	gdk_draw_drawable (GDK_DRAWABLE (drawing_area->window),
 			   drawing_area->style->fg_gc[GTK_WIDGET_STATE (drawing_area)],
 			   buffer_pixmap, 0, 0, 0, 0,
@@ -558,31 +586,6 @@ main_loop (gpointer data)
 	return (TRUE);
 }
 
-void
-update_score_state (void)
-{
-        gchar **names = NULL;
-        gfloat *scores = NULL;
-        time_t *scoretimes = NULL;
-	gint top;
-
-	gchar *buf = NULL;
-	buf = g_strdup_printf ("%d.%d", properties->gamespeed,
-			       properties->fakes);
-
-	top = gnome_score_get_notable ("gnibbles", buf,
-				       &names, &scores, &scoretimes);
-	g_free (buf);
-	if (top > 0) {
-		gtk_action_set_sensitive (scores_action, TRUE);
-		g_strfreev (names);
-		g_free (scores);
-		g_free (scoretimes);
-	} else {
-		gtk_action_set_sensitive (scores_action, FALSE);
-	}
-}
-
 static gboolean
 show_cursor_cb (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
@@ -601,7 +604,7 @@ static const GtkActionEntry action_entry[] = {
 	{ "SettingsMenu", NULL, N_("_Settings") },
 	{ "HelpMenu", NULL, N_("_Help") },
 	{ "NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (new_game_cb) },
-	{ "NewNetworkGame", GAMES_STOCK_NEW_GAME, "New Net_work Game", NULL, NULL, G_CALLBACK (new_network_game_cb) },
+	{ "NewNetworkGame", NULL, "New Net_work Game", NULL, NULL, G_CALLBACK (new_network_game_cb) },
 	{ "Pause", GAMES_STOCK_PAUSE_GAME, NULL, NULL, NULL, G_CALLBACK (pause_game_cb) },
 	{ "EndGame", GAMES_STOCK_END_GAME, NULL, NULL, NULL, G_CALLBACK (end_game_cb) },
 	{ "Scores", GAMES_STOCK_SCORES, NULL, NULL, NULL, G_CALLBACK (show_scores_cb) },
@@ -780,26 +783,28 @@ render_logo (void)
 int 
 main (int argc, char **argv)
 {
-	gnome_score_init ("gnibbles");
+	GnomeProgram *program;
+
+	setgid_io_init ();
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 	
-	gnome_program_init ("gnibbles", VERSION, LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_PARAM_POPT_TABLE, NULL,
-			    GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
-			    NULL);
+	program = gnome_program_init ("gnibbles", VERSION, LIBGNOMEUI_MODULE,
+				      argc, argv,
+				      GNOME_PARAM_POPT_TABLE, NULL,
+				      GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
+				      NULL);
 	gtk_window_set_default_icon_name ("gnome-nibbles");
 	srand (time (NULL));
 
+	highscores = games_scores_new (&scoredesc);
+
 	load_properties ();
 
 	setup_window ();
 
-	update_score_state ();
-
 	gnibbles_load_logo (window);
 	gnibbles_load_pixmap (window);
 
@@ -817,6 +822,10 @@ main (int argc, char **argv)
 
 	gtk_main ();
 
+	gnome_accelerators_sync();
+
+	g_object_unref (program);
+
 	return 0;
 }
 
