@@ -672,10 +672,12 @@ const char ui_description[] =
 
 /* Session Options */
 
-static const struct poptOption options[] = {
-  { NULL, 'x', POPT_ARG_INT, &session_xpos, 0, NULL, NULL },
-  { NULL, 'y', POPT_ARG_INT, &session_ypos, 0, NULL, NULL },
-  { NULL, '\0', 0, NULL, 0 }
+static const GOptionEntry options[] = {
+  { "x", 'x', 0, G_OPTION_ARG_INT, &session_xpos, N_("X location of window"), 
+   N_("X")},
+  { "y", 'y', 0, G_OPTION_ARG_INT, &session_ypos, N_("Y location of window"), 
+   N_("Y")},
+  { NULL }
 };
 
 /* ------------------------------------------------------- */
@@ -684,22 +686,26 @@ int
 main (int argc, char **argv)
 {
   GnomeClient *client;
+  GnomeProgram *program;
   GtkWidget *vbox;
   GtkWidget *menubar;
   gint win_width, win_height, startup_level;
+  GOptionContext *context;
 
   gnome_score_init (APPNAME);
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
   
-  gnome_program_init (APPNAME, VERSION,
-                       LIBGNOMEUI_MODULE,
-                       argc, argv,
-                       GNOME_PARAM_POPT_TABLE, options,
-                       GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+  context = g_option_context_new ("");
+  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+  program = gnome_program_init (APPNAME, VERSION,
+                                LIBGNOMEUI_MODULE,
+                                argc, argv,
+                                GNOME_PARAM_GOPTION_CONTEXT, context,
+                                GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
   games_stock_init ();
-  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnotski-icon.png");
+  gtk_window_set_default_icon_name ("gnome-klotski.png");
   client = gnome_master_client ();
   g_object_ref (G_OBJECT (client));
   gtk_object_sink (GTK_OBJECT (client));
@@ -746,6 +752,8 @@ main (int argc, char **argv)
   gtk_main ();
 
   gnome_accelerators_sync();
+
+  g_object_unref (program);
   
   return 0;
 }
@@ -1539,9 +1547,13 @@ about_cb (GtkAction *action)
                          "name", _(APPNAME_LONG),
                          "version", VERSION,
                          "comments", _("Sliding Block Puzzles"),
-                         "copyright", "Copyright \xc2\xa9 1999-2004 Lars Rydlinge",
+                         "copyright", "Copyright \xc2\xa9 1999-2006 Lars Rydlinge",
+                         "license", "GPL 2+",
                          "authors", authors,
                          "documenters", documenters,
                          "translator_credits", _("translator-credits"),
+                         "logo-icon-name", "gnome-klotski",
+                         "website", "http://www.gnome.org/projects/gnome-games/",
+                         "wrap-license", TRUE,
                          NULL);
 }
