@@ -24,7 +24,6 @@
 #include <gnome.h>
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <games-clock.h>
 #include <games-gconf.h>
@@ -109,10 +108,11 @@ static const GamesScoresDescription scoredesc = {NULL,
 
 enum {
 	GAME_RUNNING = 0,
+	GAME_WAITING,
 	GAME_WON,
 	GAME_LOST,
 	GAME_DEAD
-} game_over = GAME_DEAD;
+} game_over = GAME_WAITING;
 
 static void clear_undo_queue (void);
 void you_won (void);
@@ -183,7 +183,9 @@ window_state_callback (GtkWidget *widget, GdkEventWindowState *event)
 static void 
 update_menu_sensitivities (void)
 {
-	gtk_action_set_sensitive (pause_action, game_over != GAME_WON);
+	gtk_action_set_sensitive (pause_action, 
+				  game_over != GAME_WON &&
+				  game_over != GAME_WAITING);
 	gtk_action_set_sensitive (restart_action, undo_state);
 
 	if (paused) {
@@ -198,6 +200,13 @@ update_menu_sensitivities (void)
 
 }
 
+static void clock_start (void)
+{
+	games_clock_start (GAMES_CLOCK (chrono));
+	game_over = GAME_RUNNING;
+	update_menu_sensitivities ();
+}
+
 /* Undo and redo sensitivity functionality. */
 static void 
 set_undoredo_state (gboolean undo, gboolean redo)
@@ -516,7 +525,7 @@ tile_event (gint tileno, gint button)
 		return;
 
 	if (!games_clock_get_seconds (GAMES_CLOCK(chrono))) 
-		games_clock_start (GAMES_CLOCK(chrono));
+		clock_start ();
 	
 	switch (button) {
 	case 1:
@@ -851,7 +860,7 @@ hint_callback (void)
 {
         gint i, j, free=0, type ;
 
-        if (paused || game_over)
+        if (paused || (game_over != GAME_RUNNING && game_over != GAME_WAITING))
                 return;
 
 	/* This prevents the flashing speeding up if the hint button is
@@ -862,6 +871,7 @@ hint_callback (void)
 	/* Snarfed from check free
 	 * Tile Free is now _so_ much quicker, it is more elegant to do a
 	 * British Library search, and safer. */
+	/* Note: British Library should probably read British Museum.  */
 
 	/* Clear any selection */
 	if (selected_tile < MAX_TILES) {
@@ -896,6 +906,7 @@ hint_callback (void)
                 
 	/* 30s penalty */
 	games_clock_add_seconds(GAMES_CLOCK(chrono), 30);
+	clock_start ();
 }
 
 static void
@@ -913,7 +924,10 @@ about_callback (void)
 		_("Maps:"),
 		"Rexford Newbould",
 		"Krzysztof Foltman",
-		"",
+		NULL
+	};
+
+	const gchar *artists [] = {
 		_("Tiles:"),
 		"Jonathan Buzzard",
 		"Jim Evans",
@@ -923,13 +937,24 @@ about_callback (void)
 		NULL
 	};
 
+	const gchar *documenters [] = {
+		"Eric Baudais",
+		NULL
+	};
+
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "name", _("Mahjongg"), 
 			       "version", VERSION,
 			       "comments", _("A matching game played with Mahjongg tiles."),
 			       "copyright", "Copyright \xc2\xa9 1998-2005 Free Software Foundation, Inc.",
+			       "license", "GPL 2+",
 			       "authors", authors,
+			       "artists", artists,
+			       "documenters", documenters,
 			       "translator_credits", _("translator-credits"),
+			       "logo-icon-name", "gnome-mahjongg",
+			       "website", "http://www.gnome.org/projects/gnome-games/",
+			       "wrap-license", TRUE,
 			       NULL);
 }
 
@@ -956,7 +981,7 @@ pause_callback (void)
         }
         else {
 		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (pause_action), FALSE);
-                games_clock_start (GAMES_CLOCK(chrono));
+                clock_start ();
                 message ("");
         }
 	noloops = FALSE;
@@ -999,7 +1024,7 @@ init_game (void)
 
         gtk_label_set_text (GTK_LABEL (tiles_label), MAX_TILES_STR);
         update_moves_left ();
-        game_over = GAME_RUNNING;
+        game_over = GAME_WAITING;
         sequence_number = 1 ;
         visible_tiles = MAX_TILES;
         selected_tile = MAX_TILES + 1;
@@ -1390,21 +1415,23 @@ main (int argc, char *argv [])
 	GtkUIManager *ui_manager;
 	GtkAccelGroup *accel_group;
 
+	GnomeProgram *program;
+
 	setgid_io_init ();
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init (APPNAME, VERSION,
-			    LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_PARAM_APP_DATADIR, DATADIR,
-			    NULL);
+	program = gnome_program_init (APPNAME, VERSION,
+				      LIBGNOMEUI_MODULE,
+				      argc, argv,
+				      GNOME_PARAM_APP_DATADIR, DATADIR,
+				      NULL);
 
 	games_stock_init ();
 
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-mahjongg.png");
+	gtk_window_set_default_icon_name ("gnome-mahjongg.png");
 
 	load_maps ();
 	init_scores ();
@@ -1505,6 +1532,8 @@ main (int argc, char *argv [])
 	gtk_main ();
 
 	gnome_accelerators_sync();
+
+	g_object_unref (program);
 	
 	return 0;
 }
